﻿using System;
using System.Diagnostics;
using OneSpanSign.Sdk;
using OneSpanSign.Sdk.Builder;
using System.IO;

namespace CheckStatusAndDownloadDocuments
{
    class CheckStatusAndDownloadDocuments
    {
        private static String API_URL = "https://sandbox.esignlive.com/api";    // Use https://apps.esignlive.com/api For Production
        private static String API_KEY = "your_api_key";

        //Alternatively
        //private static String CLIENT_APP_ID = "your_client_id";
        //private static String CLIENT_APP_SECRET = "your_client_secret";
        //private static String BASE_API_URL = "https://sandbox.esignlive.com";    // Use https://apps.esignlive.com For Production
        //private static String API_URL = BASE_API_URL + "/api";

        public static void Main(string[] args)
        {
            OssClient ossClient = new OssClient(API_KEY, API_URL);

            //Alternatively
            //OssClient ossClient = new OssClient(new ApiTokenConfig
            //{
            //    ClientAppId = CLIENT_APP_ID,
            //    ClientAppSecret = CLIENT_APP_SECRET,
            //    BaseUrl = BASE_API_URL,
            //    TokenType = ApiTokenType.OWNER
            //},
            //BASE_API_URL + "/api", false, null, new Dictionary<string,string>());

            PackageId packageId = new PackageId("YOUR_PACKAGE_ID");
            DocumentPackage sentPackage = ossClient.GetPackage(packageId);

            DocumentPackageStatus packageStatus = sentPackage.Status;
            Debug.WriteLine("Package Status: " + packageStatus);

            SigningStatus signingStatus = ossClient
                            .GetSigningStatus(packageId, null, null);
            Debug.WriteLine("Signing Status: " + signingStatus);

            if (signingStatus.ToString().Equals("SIGNING_PENDING"))
            {
                Debug.WriteLine("Cannot Download: Signing not complete");
            }
            else
            {
                byte[] zipContent = ossClient.DownloadZippedDocuments(packageId);
                File.WriteAllBytes(Directory.GetCurrentDirectory()
                                    + "/package-documents.zip", zipContent);
                Debug.WriteLine("Document Zip File Downloaded");

                byte[] evidenceContent = ossClient
                                    .DownloadEvidenceSummary(packageId);
                File.WriteAllBytes(Directory.GetCurrentDirectory()
                                    + "/evidence-summary.pdf", evidenceContent);
                Debug.WriteLine("Evidence Summary Downloaded");
            }
        }
    }
}